﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Printing;
using Infragistics.Windows.Reporting;

namespace ReportingLandscapeApplication
{
    
    public partial class ReportingLandscape : Window
    {
        List<string> filters = new List<string>();
        DateTime startDate = new DateTime(2003, 1, 1);
        DateTime endDate = new DateTime(2008, 1, 1);
        public ReportingLandscape()
        {
            InitializeComponent();
            filters.Add("filter1");
            filters.Add("filter2");
            filters.Add("filter3");
        }

        /*Generates Landscape Print Preview.
          To print the generated print preview you have to manually set the document orientation to Landscape */
        private void printPreviewButton_Click(object sender, RoutedEventArgs e)
        {
            Report reportObj = new Report();
            reportObj.PageHeaderTemplate = this.Resources["PagePresenterHeaderTemplate"] as DataTemplate;
            DateTime now = DateTime.Now;
            string filterString = "";
            if (filters.Count() > 0)
                filterString = "Filtered by ";
            foreach (var f in filters)
                filterString += string.Format("-{0}\n", f);

            reportObj.PageHeader = string.Format("Sales Report From {0:MM/dd/yyyy} To {1:MM/dd/yyyy} \nDate Run {2:MM/dd/yyyy} \n {3}",
                startDate, endDate, now, filterString);

            EmbeddedVisualReportSection section;
            section = new EmbeddedVisualReportSection(xamChart1);

            // 3. Add created section to report's section collection
            reportObj.ReportSettings.HorizontalPaginationMode = HorizontalPaginationMode.Scale;
            reportObj.Sections.Add(section);

            PrintTicket pt = new PrintTicket();
            pt.PageOrientation = System.Printing.PageOrientation.Landscape;

            PrintQueue pq = LocalPrintServer.GetDefaultPrintQueue();
            pq.UserPrintTicket = pt;

            PrintDialog pd = new PrintDialog();
            pd.PrintTicket = pt;
            pd.PrintQueue = pq;

            pd.PrintQueue.UserPrintTicket = pd.PrintTicket;
            reportObj.ReportSettings.PrintQueue = pd.PrintQueue;
          
            double h = pd.PrintableAreaHeight;
            double w = pd.PrintableAreaWidth;
            reportObj.ReportSettings.PageSize = new Size(w, h);
            xamReportPreview1.GeneratePreview(reportObj, false, true);
            xamReportPreview1.Visibility = Visibility.Visible;
        }

        /*Prints the document using landscape orientation without generating any print preview.*/
        private void printWithoutPrintPreviewButton_Click(object sender, RoutedEventArgs e)
        {
            Report reportObj = new Report();
            reportObj.PageHeaderTemplate = this.Resources["PagePresenterHeaderTemplate"] as DataTemplate;
            DateTime now = DateTime.Now;
            string filterString = "";
            if (filters.Count() > 0)
                filterString = "Filtered by ";
            foreach (var f in filters)
                filterString += string.Format("-{0}\n", f);

            reportObj.PageHeader = string.Format("Sales Report From {0:MM/dd/yyyy} To {1:MM/dd/yyyy} \nDate Run {2:MM/dd/yyyy} \n {3}",
                startDate, endDate, now, filterString);

            EmbeddedVisualReportSection section;
            section = new EmbeddedVisualReportSection(xamChart1);

            // 3. Add created section to report's section collection
            reportObj.ReportSettings.HorizontalPaginationMode = HorizontalPaginationMode.Scale;
            reportObj.Sections.Add(section);

            PrintTicket pt = new PrintTicket();
            pt.PageOrientation = System.Printing.PageOrientation.Landscape;

            PrintQueue pq = LocalPrintServer.GetDefaultPrintQueue();
            pq.UserPrintTicket = pt;

            PrintDialog pd = new PrintDialog();
            pd.PrintTicket = pt;
            pd.PrintQueue = pq;

            pd.PrintQueue.UserPrintTicket = pd.PrintTicket;
            reportObj.ReportSettings.PrintQueue = pd.PrintQueue;
            reportObj.Print(false, false);
        }

        private void printPrev_Checked(object sender, RoutedEventArgs e)
        {
            printPreviewButton.IsEnabled = true;
            printWithoutPrintPreviewButton.IsEnabled = false;
        }

        private void printOnly_Checked(object sender, RoutedEventArgs e)
        {
            xamReportPreview1.Visibility = Visibility.Collapsed;
            printWithoutPrintPreviewButton.IsEnabled = true;
            printPreviewButton.IsEnabled = false;
        }
    }
}
